@@ -2,10 +2,14 @@ package operatorsource
 
 import (
 	"context"
+	"time"
 
-	marketplace "github.com/operator-framework/operator-marketplace/pkg/apis/operators/v1"
+	"github.com/operator-framework/operator-marketplace/pkg/apis/operators/v1"
+	"github.com/operator-framework/operator-marketplace/pkg/defaults"
+	"github.com/operator-framework/operator-marketplace/pkg/operatorhub"
 	operatorsourcehandler "github.com/operator-framework/operator-marketplace/pkg/operatorsource"
 	"github.com/operator-framework/operator-marketplace/pkg/status"
+	"github.com/operator-framework/operator-marketplace/pkg/watches"
 	log "github.com/sirupsen/logrus"
 	"k8s.io/apimachinery/pkg/api/errors"
 	"sigs.k8s.io/controller-runtime/pkg/client"
@@ -22,8 +26,8 @@ func Add(mgr manager.Manager) error {
 	return add(mgr, newReconciler(mgr))
 }
 
-// newReconciler returns a new reconcile.Reconciler
-func newReconciler(mgr manager.Manager) reconcile.Reconciler {
+// newReconciler returns a new ReconcileOperatorSource
+func newReconciler(mgr manager.Manager) *ReconcileOperatorSource {
 	client := mgr.GetClient()
 	handler := operatorsourcehandler.NewHandler(mgr, client)
 	return &ReconcileOperatorSource{
@@ -32,8 +36,8 @@ func newReconciler(mgr manager.Manager) reconcile.Reconciler {
 	}
 }
 
-// add adds a new Controller to mgr with r as the reconcile.Reconciler
-func add(mgr manager.Manager, r reconcile.Reconciler) error {
+// add adds a new Controller to mgr with r as the ReconcileOperatorSource
+func add(mgr manager.Manager, r *ReconcileOperatorSource) error {
 	// Create a new controller
 	c, err := controller.New("operatorsource-controller", mgr, controller.Options{Reconciler: r})
 	if err != nil {
@@ -41,7 +45,13 @@ func add(mgr manager.Manager, r reconcile.Reconciler) error {
 	}
 
 	// Watch for changes to primary resource OperatorSource
-	err = c.Watch(&source.Kind{Type: &marketplace.OperatorSource{}}, &handler.EnqueueRequestForObject{})
+	err = c.Watch(&source.Kind{Type: &v1.OperatorSource{}}, &handler.EnqueueRequestForObject{})
+	if err != nil {
+		return err
+	}
+
+	// Watch for child resource deletions
+	err = watches.WatchChildResourcesDeletionEvents(c, r.client, v1.OperatorSourceKind)
 	if err != nil {
 		return err
 	}
@@ -68,10 +78,19 @@ func (r *ReconcileOperatorSource) Reconcile(request reconcile.Request) (reconcil
 	status.SendSyncMessage(nil)
 
 	// Fetch the OperatorSource instance
-	instance := &marketplace.OperatorSource{}
+	instance := &v1.OperatorSource{}
 	err := r.client.Get(context.TODO(), request.NamespacedName, instance)
 	if err != nil {
 		if errors.IsNotFound(err) {
+			// If the object is not found but is one of the default operator sources, let's ensure it gets recreated.
+			if defaults.IsDefaultSource(request.Name) {
+				err = defaults.New(defaults.GetGlobalDefinitions(), operatorhub.GetSingleton().Get()).Ensure(r.client, request.Name)
+				if err != nil {
+					// If we run into an error when attempting to ensure the default, let's requeue and try again
+					return reconcile.Result{}, err
+				}
+			}
+
 			// Request object not found, could have been deleted after reconcile request.
 			// Owned objects are automatically garbage collected. For additional cleanup logic use finalizers.
 			// Return and don't requeue
@@ -85,10 +104,13 @@ func (r *ReconcileOperatorSource) Reconcile(request reconcile.Request) (reconcil
 	// Needed because sdk does not get the gvk
 	instance.EnsureGVK()
 
-	err = r.OperatorSourceHandler.Handle(context.TODO(), instance)
+	requeue, err := r.OperatorSourceHandler.Handle(context.TODO(), instance)
 	if err != nil {
 		return reconcile.Result{}, err
 	}
+	if requeue {
+		return reconcile.Result{RequeueAfter: time.Second * 5}, nil
+	}
 
 	return reconcile.Result{}, nil
 }
