@@ -32,6 +32,8 @@ const (
 	portNumber                 = 50051
 	portName                   = "grpc"
 	deploymentUpdateAnnotation = "openshift-marketplace-update-hash"
+	linuxNodeSelectorKey       = "beta.kubernetes.io/os"
+	linuxNodeSelectorValue     = "linux"
 )
 
 var action = []string{"grpc_health_probe", "-addr=localhost:50051"}
@@ -415,6 +417,9 @@ func (r *registry) newPodTemplateSpec(registryCommand []string, needServiceAccou
 					},
 				},
 			},
+			NodeSelector: map[string]string{
+				linuxNodeSelectorKey: linuxNodeSelectorValue,
+			},
 		},
 	}
 	if needServiceAccount {
